@@ -1,13 +1,20 @@
-# $Id: Cygwin.pm,v 1.3 2008/10/27 20:31:21 drhyde Exp $
+# $Id: Cygwin.pm,v 1.4 2008/11/05 22:52:34 drhyde Exp $
 
 package Devel::AssertOS::Cygwin;
 
 use Devel::CheckOS;
 
-$VERSION = '1.1';
+$VERSION = '1.2';
 
 sub os_is { $^O eq 'cygwin' ? 1 : 0; }
 
+sub expn {
+join("\n",
+"The operating system is Microsoft Windows, but perl was built using",
+"the POSIXish API provided by Cygwin"
+)
+}
+
 Devel::CheckOS::die_unsupported() unless(os_is());
 
 =head1 COPYRIGHT and LICENCE
