@@ -7,7 +7,7 @@ use Exporter;
 
 use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION = '1.6';
+$VERSION = '1.61';
 
 # localising prevents the warningness leaking out of this module
 local $^W = 1;    # use warnings is a 5.6-ism
@@ -26,10 +26,17 @@ Devel::CheckOS - check what OS we're running on
 
 =head1 DESCRIPTION
 
+A learned sage once wrote on IRC:
+
+   $^O is stupid and ugly, it wears its pants as a hat
+
 Devel::CheckOS provides a more friendly interface to $^O, and also lets
 you check for various OS "families" such as "Unix", which includes things
 like Linux, Solaris, AIX etc.
 
+It spares perl the embarrassment of wearing its pants on its head by
+covering them with a splendid Fedora.
+
 =head1 SYNOPSIS
 
     use Devel::CheckOS qw(os_is);
@@ -72,16 +79,17 @@ of OSes and OS families, eg ...
 
 sub os_is {
     my @targets = @_;
+    my $rval = 0;
     foreach my $target (@targets) {
         die("Devel::CheckOS: $target isn't a legal OS name\n")
             unless($target =~ /^\w+(::\w+)*$/);
         eval "use Devel::AssertOS::$target";
         if(!$@) {
             no strict 'refs';
-            return 1 if(&{"Devel::AssertOS::${target}::os_is"}());
+            $rval = 1 if(&{"Devel::AssertOS::${target}::os_is"}());
         }
     }
-    return 0;
+    return $rval;
 }
 
 =head3 os_isnt
@@ -93,10 +101,11 @@ otherwise it returns true.
 
 sub os_isnt {
     my @targets = @_;
+    my $rval = 1;
     foreach my $target (@targets) {
-        return 0 if(os_is($target));
+        $rval = 0 if(os_is($target));
     }
-    return 1;
+    return $rval;
 }
 
 =head2 Fatal functions
@@ -279,6 +288,8 @@ L<Probe::Perl>
 
 The use-devel-assertos script
 
+L<Module::Install::AssertOS>
+
 =head1 AUTHOR
 
 David Cantrell E<lt>F<david@cantrell.org.uk>E<gt>
@@ -307,6 +318,10 @@ Copyright 2007 David Cantrell
 
 This software is free-as-in-speech software, and may be used, distributed, and modified under the terms of either the GNU General Public Licence version 2 or the Artistic Licence. It's up to you which one you use. The full text of the licences can be found in the files GPL2.txt and ARTISTIC.txt, respectively.
 
+=head1 HATS
+
+I recommend buying a Fedora from L<http://hatsdirect.com/>.
+
 =head1 CONSPIRACY
 
 This module is also free-as-in-mason software.
